@@ -1,3 +1,9 @@
+//! [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](./LICENSE-MIT)
+//! [![Apache License 2.0](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](./LICENSE-APACHE)
+//! [![Crates.io Version](https://img.shields.io/crates/v/tls-parser.svg)](https://crates.io/crates/tls-parser)
+//! [![GitHub CI](https://github.com/cpu/tls-parser/actions/workflows/rust.yml/badge.svg)](https://github.com/cpu/tls-parser/actions/workflows/rust.yml)
+//! [![Minimum rustc version](https://img.shields.io/badge/rustc-1.70.0+-lightgray.svg)](#rust-version-requirements)
+//!
 //! # TLS Parser
 //!
 //! A TLS parser, implemented with the [nom](https://github.com/Geal/nom)
@@ -12,6 +18,10 @@
 //! See [the rusticata TLS parser](https://github.com/rusticata/rusticata/blob/master/src/tls.rs)
 //! for a full example.
 //!
+//! It is written in pure Rust, fast, and makes extensive use of zero-copy. A lot of care is taken
+//! to ensure security and safety of this crate, including design (recursion limit, defensive
+//! programming), tests, and fuzzing. It also aims to be panic-free.
+//!
 //! The code is available on [Github](https://github.com/rusticata/tls-parser)
 //! and is part of the [Rusticata](https://github.com/rusticata) project.
 //!
@@ -25,13 +35,9 @@
 //! # Examples
 //!
 //! ```rust
-//! extern crate nom;
-//! extern crate tls_parser;
-//!
-//! use nom::{Err, IResult};
 //! use tls_parser::parse_tls_plaintext;
+//! use tls_parser::nom::{Err, IResult};
 //!
-//! # fn main() {
 //! let bytes : &[u8]= include_bytes!("../assets/client_hello_dhe.bin");
 //! // [ 0x16, 0x03, 0x01 ... ];
 //! let res = parse_tls_plaintext(&bytes);
@@ -45,7 +51,6 @@
 //!     },
 //!     Err(e) => { eprintln!("parse_tls_record_with_header failed: {:?}",e); }
 //! }
-//! # }
 //! ```
 //!
 //! Note that knowing if a record is plaintext or not is the responsibility of the caller.
@@ -57,17 +62,14 @@
 //! Here is an example of two-steps parsing:
 //!
 //! ```rust
-//! # extern crate nom;
-//! # extern crate tls_parser;
-//! # use nom::{Err, IResult};
 //! # use tls_parser::{parse_tls_raw_record, parse_tls_record_with_header};
+//! # use tls_parser::nom::{Err, IResult};
 //!
-//! # fn main() {
 //! # let bytes : &[u8]= include_bytes!("../assets/client_hello_dhe.bin");
 //! // [ 0x16, 0x03, 0x01 ... ];
 //! match parse_tls_raw_record(bytes) {
 //!     Ok((rem, ref r)) => {
-//!         match parse_tls_record_with_header(r.data,r.hdr.clone()) {
+//!         match parse_tls_record_with_header(r.data, &r.hdr) {
 //!             Ok((rem2,ref msg_list)) => {
 //!                 for msg in msg_list {
 //!                     // msg has type TlsMessage
@@ -80,7 +82,6 @@
 //!     Err(Err::Incomplete(needed)) => { eprintln!("incomplete record header") }
 //!     Err(_) => { eprintln!("error while parsing record header") }
 //! }
-//! # }
 //! ```
 //!
 //! Some additional work is required if reading packets from the network, to support
@@ -101,10 +102,8 @@
 //! it returns `Ok(new_state)`, otherwise it returns `Err(error_state)`.
 //!
 //! ```rust
-//! # extern crate nom;
-//! # extern crate tls_parser;
-//! # use nom::{Err, IResult};
 //! # use tls_parser::{tls_state_transition, TlsMessage, TlsState};
+//! # use tls_parser::nom::{Err, IResult};
 //!
 //! struct ParseContext {
 //!     state: TlsState,
@@ -128,52 +127,54 @@
 //! it allows to read invalid values and continue parsing (for an IDS, it's better to read
 //! values than to get a generic parse error).
 
-#![deny(/*missing_docs,*/unsafe_code,
+#![deny(/*missing_docs,*/
         unstable_features,
         /*unused_import_braces,*/ unused_qualifications)]
+#![forbid(unsafe_code)]
+#![allow(clippy::upper_case_acronyms)]
+#![no_std]
 
+#[cfg(any(test, feature = "std"))]
 #[macro_use]
-extern crate enum_primitive;
+extern crate std;
 
-#[macro_use]
-extern crate nom;
-
-extern crate phf;
-
-#[macro_use]
-extern crate rusticata_macros;
-
-#[cfg(feature = "serialize")]
-extern crate cookie_factory;
-
-pub use tls_alert::*;
-/// TLS alerts
-#[macro_use]
-pub mod tls_alert;
-pub use tls_ciphers::*;
-/// TLS ciphersuites definitions and parameters
-pub mod tls_ciphers;
-pub use tls_dh::*;
-/// Diffie-Hellman parameters
-pub mod tls_dh;
-pub use tls_ec::*;
-/// Elliptic curves
-pub mod tls_ec;
-pub use tls_extensions::*;
-/// TLS extensions
-#[macro_use]
-pub mod tls_extensions;
-pub use tls_sign_hash::*;
-/// TLS signature schemes
-pub mod tls_sign_hash;
-pub use tls_states::*;
-/// TLS state machine
-pub mod tls_states;
-pub use tls::*;
-/// TLS parser structures and functions
-pub mod tls;
+extern crate alloc;
 
+mod certificate_transparency;
+mod dtls;
+mod tls_alert;
+mod tls_ciphers;
 mod tls_debug;
+mod tls_dh;
+mod tls_ec;
+mod tls_extensions;
+mod tls_handshake;
+mod tls_message;
+mod tls_record;
+mod tls_sign_hash;
+mod tls_states;
 
-pub mod tls_serialize;
+pub use certificate_transparency::*;
+pub use dtls::*;
+pub use tls_alert::*;
+pub use tls_ciphers::*;
+pub use tls_dh::*;
+pub use tls_ec::*;
+pub use tls_extensions::*;
+pub use tls_handshake::*;
+pub use tls_message::*;
+pub use tls_record::*;
+pub use tls_sign_hash::*;
+pub use tls_states::*;
+
+#[cfg(all(feature = "serialize", not(feature = "std")))]
+compile_error!("features `serialize` cannot be enabled when using `no_std`");
+
+#[cfg(all(feature = "serialize", feature = "std"))]
+mod tls_serialize;
+#[cfg(feature = "serialize")]
 pub use tls_serialize::*;
+
+pub use nom;
+pub use nom::{Err, IResult};
+pub use rusticata_macros;
